@@ -38,7 +38,7 @@ class Logger(object):
 
 if not os.path.exists('/log/'):  # 判断是否存在文件夹如果不存在则创建为文件夹
     try:
-        os.makedirs(os.path.abspath('.') + log_path)  # makedirs 创建文件时如果路径不存在会创建这个路径
+        os.makedirs(os.path.abspath('.') + '/log/')  # makedirs 创建文件时如果路径不存在会创建这个路径
     except Exception as ex:
         print(ex)
         pass
